[−][src]Crate gstuff
Modules
| oneshot | Reason for having this is that neither |
Macros
| ERR | Returns a |
| ERRL | Prepends file name and line number to the given message. |
| find_parse_replace_s | Uses nom to find all matches of the given |
| gstring | A helper to build a string on the stack. |
| parse_replace_s | Uses nom to find all matches of the given |
| take_until_find_parse_s |
|
| take_until_parse_s | Implements the |
| try_f | Returns on error, prepending the current location to a stringified error, then passing the string to |
| try_fu | Lifts an error into a boxed future. |
| try_fus | Lifts an error into a boxed future. |
| try_s | Returns on error, converting the |
| try_sp | Like |
Structs
| Constructible | A cell that can be initialized, but only once. |
| FileLock | Allows several threads or processes to compete for a shared resource by tracking resource ownership with a file. |
| ProcEn | Process entry in /proc. |
| ProcIt | Iterate over processes in /proc. |
Functions
| any_to_str | Useful with panic handlers. |
| binprint | Helps logging binary data (particularly with text-readable parts, such as bencode, netstring)
by replacing all the non-printable bytes with the |
| cmd | Run a command, printing it first. Stdout and stderr are forwarded through ( |
| duration_to_float | Converts the duration into a number of seconds with fractions. |
| duration_to_ms | Converts the duration into a number of milliseconds. |
| filename | Shortcut to path->filename conversion. |
| last_modified_sec | Last-modified of the file in seconds since the UNIX epoch, with fractions. |
| ms2sec | Converts time in milliseconds into a number of seconds with fractions. |
| netstring | Takes a netstring from the front of the slice. |
| now_float | The current number of seconds since UNIX epoch, with fractions. |
| now_ms | The current number of milliseconds since UNIX epoch. |
| slurp | Read contents of the file into a |
| slurp_prog | Runs a command in a shell, returning stderr+stdout on success. |
| with_hostname | Wraps |